@@ -92,8 +92,8 @@ def SyncDataTypeFromSkynamoToLocalJsonFiles(dataType,fullSync=False,syncFromLast
 	if exceptionThatOccured!=None:
 		raise exceptionThatOccured
 
-def SyncDataTypesFromSkynamo(dataTypes:List[Literal['prices','warehouses','completedforms','quotes','orders','creditrequests','users','stocklevels','customers','products','invoices','formdefinitions','interactions']]=['completedforms','quotes','orders','creditrequests','users','stocklevels','customers','products','invoices','interactions']):
-	fullSyncDataTypes=['users','stocklevels','formdefinitions']
+def SyncDataTypesFromSkynamo(dataTypes:List[Literal['taxrates','prices','warehouses','completedforms','quotes','orders','creditrequests','users','stocklevels','customers','products','invoices','formdefinitions','interactions']]=['completedforms','quotes','orders','creditrequests','users','stocklevels','customers','products','invoices','interactions']):
+	fullSyncDataTypes=['users','stocklevels','formdefinitions','taxrates','warehouses']
 	versionedDataTypes=['customers','products','invoices']
 	dataTypeFlags={'formdefinitions':['show_enums'],'orders':['show_nulls'],'creditrequests':['show_nulls'],'quotes':['show_nulls']}
 	flags=[]
@@ -108,7 +108,7 @@ def SyncDataTypesFromSkynamo(dataTypes:List[Literal['prices','warehouses','compl
 			flags=dataTypeFlags[dataType]
 		SyncDataTypeFromSkynamoToLocalJsonFiles(dataType,fullSync,syncFromLastRowVersion,flags)
 
-def refreshJsonFilesLocallyIfOutdated(dataTypes:List[Literal['prices','warehouses','completedforms','quotes','orders','creditrequests','users','stocklevels','customers','products','invoices','formdefinitions','interactions']],forceRefresh:bool=False):
+def refreshJsonFilesLocallyIfOutdated(dataTypes:List[Literal['taxrates','prices','warehouses','completedforms','quotes','orders','creditrequests','users','stocklevels','customers','products','invoices','formdefinitions','interactions']],forceRefresh:bool=False):
 	import os
 	import time
 	nrSecondsToWaitBeforeRefreshing=300
